@@ -16,7 +16,7 @@ def get_args() -> argparse.Namespace:
     )
 
     parser.add_argument(
-        '--quiz_questions_folder_path',
+        '--export_quiz_content_to_redis',
         type=str,
         help='Specify path to folder with quiz questions files',
     )
@@ -27,7 +27,7 @@ def main() -> None:
     """Entry point."""
     args = get_args()
     start_bot = args.start_bot
-    quiz_questions_folder_path = args.quiz_questions_folder_path
+    quiz_questions_folder_path = args.export_quiz_content_to_redis
 
     if start_bot == 'tg':
         start_tg_bot()
